==> owncloud-news_6.1.1%2Bdfsg.orig.tar.gz: news-6.1.1/l10n/nl.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "Feed bevat ongeldige XML",
    "Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" : "Feed niet gevonden: ofwel de website levert geen feed, of de toegang is geblokkeerd. Om te zien of geblokkeerd wordt: probeer de feed via de commandoregel van uw server op te halen met curl: curl http://de-feed.tld",
    "Detected feed format is not supported" : "Gevonden feed formaat wordt niet ondersteund",
    "SSL Certificate is invalid" : "SSL certificaat is ongeldig",
    "Website not found" : "Website niet gevonden",
    "More redirects than allowed, aborting" : "Meer doorverwijzingen dan toegestaan, afgebroken",
    "Bigger than maximum allowed size" : "Groter dan maximaal toegestane omvang",
    "Request timed out" : "Aanvraag time-out",
    "Request failed, network connection unavailable!" : "Aanvraag mislukt, netwerkverbinding niet beschikbaar!",
    "Request unauthorized. Are you logged in?" : "Aanvraag niet toegestaan. Bent u ingelogd?",
    "Request forbidden. Are you an admin?" : "Aanvraag verboden. Bent u beheerder?",
    "Token expired or app not enabled! Reload the page!" : "Token verlopen of app niet ingeschakeld! Ververs de pagina!",
    "Internal server error! Please check your " : "Interne serverfout! Verifieer uw",
    "Request failed, ownCloud is in currently " : "Aanvraag mislukt, ownCloud is nu in",
    "Can not add feed: Exists already" : "Kan feed niet toevoegen: bestaat al",
    "Articles without feed" : "Artikelen zonder feed",
    "Can not add folder: Exists already" : "Kan map niet toevoegen, bestaat al",
    "Use ownCloud cron for updates" : "Gebruik ownCloud cron voor updates",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Schakel dit uit als u een maatwerk updater gebruikt, zoals de Python updater bij de app",
    "Purge interval" : "Opruim interval",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minimum aantal seconden waarna verwijderde feeds en mappen worden opgeruimd uit de database; waarden onder 60 seconden worden genegeerd",
    "Maximum read count per feed" : "Maximaal aantal gelezen per feed",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Bepaalt het maximale aantal artikelen dat per feed kan worden gelezen voordat ze door de schoonmaak job worden verwijderd. Als oude artikelen opnieuw verschijnen na het lezen, verhoog dan de waarde; een negatieve waarde, zoals -1, schakelt deze functie uit",
    "Maximum redirects" : "Maximum redirects",
    "How many redirects the feed fetcher should follow" : "Hoeveel redirects de feed ophaler moet volgen",
    "Maximum feed page size" : "Maximum feed paginagrootte",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximale feed-omvang in bytes. Als de RSS/Atom pagina groter is, dan zal bijwerken worden afgebroken",
    "Feed fetcher timeout" : "Feed ophaler timeout",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximum aantal seconden om te wachten op een RSS of Atom feed te laden; als het langer duurt, zal het bijwerken worden afgebroken.",
    "Explore Service URL" : "Verken service URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Wanneer opgegeven zal de URL van deze service worden geraadpleegd om feeds in de verken feed sectie te tonen. Laat dit blanco om terug te vallen op de ingebouwde verkenner service.",
    "Saved" : "Bewaard",
    "Download" : "Downloaden",
    "Close" : "Sluiten",
    "Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "Ajax- of webcron modus gedetecteerd! Uw feeds worden niet correct bijgewerkt. Geadviseerd wordt om ofwel de cron-service van het platform zelf te gebruiken of een eigen maatwerk updater.",
    "How to set up the operating system cron" : "Hoe wordt de cron-service van het operating system ingesteld",
    "How to set up a custom updater (faster and no possible deadlock) " : "Hoe wordt een maarwerk update ingesteld (sneller en geen deadlock)",
    "Subscribe" : "Abonneren",
    "Refresh" : "Vernieuwen",
    "No articles available" : "Geen artikelen beschikbaar",
    "No unread articles available" : "Geen ongelezen artikelen beschikbaar",
    "Open website" : "Open website",
    "Star article" : "Markeer artikel",
    "Unstar article" : "Demarkeer artikel",
    "Keep article unread" : "Bewaar artikel als ongelezen",
    "Remove keep article unread" : "Verwijder ongelezen houden artikel",
    "by" : "door",
    "from" : "van",
    "Play audio" : "Audio afspelen",
    "Download video" : "Downloaden video",
    "Download audio" : "Downloaden audio",
    "Keyboard shortcut" : "Sneltoets",
    "Description" : "Beschrijving",
    "right" : "rechts",
    "Jump to next article" : "Ga naar volgend artikel",
    "left" : "links",
    "Jump to previous article" : "Ga naar voorgaand artikel",
    "Toggle star article" : "Omswitchen artikelmarkering ",
    "Star article and jump to next one" : "Markeer artikel en ga naar volgende",
    "Toggle keep current article unread" : "Omswitchen hou huidig artikel ongelezen",
    "Open article in new tab" : "Open artikel in nieuwe tab",
    "Toggle expand article in compact view" : "Omswitchen uitgebreid artikel in compact overzicht",
    "Load next feed" : "Laad volgende feed",
    "Load previous feed" : "Laad voorgaande feed",
    "Load next folder" : "Laad volgende map",
    "Load previous folder" : "Laad voorgaande map",
    "Scroll to active navigation entry" : "Scrollen naar actieve navigatie regel",
    "Focus search field" : "Focus zoekveld",
    "Mark current article's feed/folder read" : "Markeer feed/map van huidige artikel als gelezen",
    "Web address" : "Webadres",
    "Feed exists already!" : "Feed bestaat al!",
    "Folder" : "Map",
    "No folder" : "Geen map",
    "New folder" : "Nieuwe map",
    "Folder name" : "Mapnaam",
    "Go back" : "Terug",
    "Folder exists already!" : "Map bestaat al!",
    "New Folder" : "Nieuwe map",
    "Create" : "Aanmaken",
    "Explore" : "Verkennen",
    "Deleted feed" : "Verwijderde feed",
    "Undo delete feed" : "Maak verwijderen feed ongedaan",
    "Rename" : "Naam wijzigen",
    "Menu" : "Menu",
    "Unpin feed from the top" : "Feed losmaken van boven",
    "Pin feed to the top" : "Feed bovenaan vastzetten",
    "No feed ordering" : "Geen feed sortering",
    "Reversed feed ordering" : "Omgekeerde feedvolgorde",
    "Normal feed ordering" : "Normale feedvolgorde",
    "Enable full text feed fetching" : "Inschakelen ophalen volledige tekst",
    "Disable full text feed fetching" : "Uitschakelen ophalen volledige tekst",
    "Keep updated articles as is" : "Hou de bijgewerkte artkelen zoals ze zijn",
    "Mark updated articles unread" : "Markeer bijgewerkte artikelen als ongelezen",
    "Rename feed" : "Hernoemen feed",
    "Delete feed" : "Verwijder feed",
    "Mark all articles read" : "Markeer alle artikelen als gelezen",
    "Dismiss" : "Terzijde leggen",
    "Collapse" : "Inklappen",
    "Deleted folder" : "Verwijderde map",
    "Undo delete folder" : "Maak verwijderen map ongedaan",
    "Rename folder" : "Hernoem map",
    "Delete folder" : "Verwijder map",
    "Starred" : "Ster gegeven",
    "Unread articles" : "Ongelezen artikelen",
    "All articles" : "Alle artikelen",
    "Settings" : "Instellingen",
    "Keyboard shortcuts" : "Sneltoetsen",
    "Disable mark read through scrolling" : "Niet als gelezen markeren door scrollen",
    "Compact view" : "Compact overzicht",
    "Expand articles on key navigation" : "Artikelen uitbreiden bij navigatie",
    "Show all articles" : "Toon alle artikelen",
    "Reverse ordering (oldest on top)" : "Omgekeerde volgorde (oudste boven)",
    "Subscriptions (OPML)" : "Abonnementen (OPML)",
    "Import" : "Importeer",
    "Export" : "Exporteer",
    "Error when importing: file does not contain valid OPML" : "Fout bij importeren: het bestand bevat geen geldige OPML",
    "Unread/Starred Articles" : "Ongelezen/ongemarkeerde artikelen",
    "Error when importing: file does not contain valid JSON" : "Fout tijdens het importeren: bestand bevat geen geldige JSON"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-news_7.1.1%2Bdfsg.orig.tar.gz: news-7.1.1/l10n/nl.js <==
OC.L10N.register(
    "news",
    {
    "Feed contains invalid XML" : "Feed bevat ongeldige XML",
    "Feed not found: either the website does not provide a feed or blocks access. To rule out blocking, try to download the feed on your server's command line using curl: curl http://the-feed.tld" : "Feed niet gevonden: ofwel de website levert geen feed, of de toegang is geblokkeerd. Om te zien of geblokkeerd wordt: probeer de feed via de commandoregel van uw server op te halen met curl: curl http://de-feed.tld",
    "Detected feed format is not supported" : "Gevonden feed formaat wordt niet ondersteund",
    "SSL Certificate is invalid" : "SSL certificaat is ongeldig",
    "Website not found" : "Website niet gevonden",
    "More redirects than allowed, aborting" : "Meer doorverwijzingen dan toegestaan, afgebroken",
    "Bigger than maximum allowed size" : "Groter dan maximaal toegestane omvang",
    "Request timed out" : "Aanvraag time-out",
    "Request failed, network connection unavailable!" : "Aanvraag mislukt, netwerkverbinding niet beschikbaar!",
    "Request unauthorized. Are you logged in?" : "Aanvraag niet toegestaan. Bent u ingelogd?",
    "Request forbidden. Are you an admin?" : "Aanvraag verboden. Bent u beheerder?",
    "Token expired or app not enabled! Reload the page!" : "Token verlopen of app niet ingeschakeld! Ververs de pagina!",
    "Internal server error! Please check your " : "Interne serverfout! Verifieer uw",
    "Request failed, ownCloud is in currently " : "Aanvraag mislukt, ownCloud is nu in",
    "Can not add feed: Exists already" : "Kan feed niet toevoegen: bestaat al",
    "Articles without feed" : "Artikelen zonder feed",
    "Can not add folder: Exists already" : "Kan map niet toevoegen, bestaat al",
    "Use ownCloud cron for updates" : "Gebruik ownCloud cron voor updates",
    "Disable this if you run a custom updater such as the Python updater included in the app" : "Schakel dit uit als u een maatwerk updater gebruikt, zoals de Python updater bij de app",
    "Purge interval" : "Opruim interval",
    "Minimum amount of seconds after deleted feeds and folders are removed from the database; values below 60 seconds are ignored" : "Minimum aantal seconden waarna verwijderde feeds en mappen worden opgeruimd uit de database; waarden onder 60 seconden worden genegeerd",
    "Maximum read count per feed" : "Maximaal aantal gelezen per feed",
    "Defines the maximum amount of articles that can be read per feed which won't be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off completely" : "Bepaalt het maximale aantal artikelen dat per feed kan worden gelezen voordat ze door de schoonmaak job worden verwijderd. Als oude artikelen opnieuw verschijnen na het lezen, verhoog dan de waarde; een negatieve waarde, zoals -1, schakelt deze functie uit",
    "Maximum redirects" : "Maximum redirects",
    "How many redirects the feed fetcher should follow" : "Hoeveel redirects de feed ophaler moet volgen",
    "Maximum feed page size" : "Maximum feed paginagrootte",
    "Maximum feed size in bytes. If the RSS/Atom page is bigger than this value, the update will be aborted" : "Maximale feed-omvang in bytes. Als de RSS/Atom pagina groter is, dan zal bijwerken worden afgebroken",
    "Feed fetcher timeout" : "Feed ophaler timeout",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted" : "Maximum aantal seconden om te wachten op een RSS of Atom feed te laden; als het langer duurt, zal het bijwerken worden afgebroken.",
    "Explore Service URL" : "Verken service URL",
    "If given, this service's URL will be queried for displaying the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty" : "Wanneer opgegeven zal de URL van deze service worden geraadpleegd om feeds in de verken feed sectie te tonen. Laat dit blanco om terug te vallen op de ingebouwde verkenner service.",
    "For more information check the Wiki" : "Bezoek de Wiki voor meer informatie",
    "Saved" : "Bewaard",
    "Download" : "Downloaden",
    "Close" : "Sluiten",
    "Ajax or webcron cron mode detected! Your feeds will not be updated correctly. It is recommended to either use the operating system cron or a custom updater." : "Ajax- of webcron modus gedetecteerd! Uw feeds worden niet correct bijgewerkt. Geadviseerd wordt om ofwel de cron-service van het platform zelf te gebruiken of een eigen maatwerk updater.",
    "How to set up the operating system cron" : "Hoe wordt de cron-service van het operating system ingesteld",
    "How to set up a custom updater (faster and no possible deadlock) " : "Hoe wordt een maatwerk update ingesteld (sneller en geen deadlock)",
    "filter" : "filter",
    "Language" : "Taal",
    "Subscribe" : "Abonneren",
    "Got more awesome feeds? Share them with us!" : "Weet u meer mooie feeds? Deel ze met ons!",
    "Refresh" : "Vernieuwen",
    "No articles available" : "Geen artikelen beschikbaar",
    "No unread articles available" : "Geen ongelezen artikelen beschikbaar",
    "Open website" : "Open website",
    "Star article" : "Markeer artikel",
    "Unstar article" : "Demarkeer artikel",
    "Keep article unread" : "Bewaar artikel als ongelezen",
    "Remove keep article unread" : "Verwijder ongelezen houden artikel",
    "by" : "door",
    "from" : "van",
    "Play audio" : "Audio afspelen",
    "Download video" : "Downloaden video",
    "Download audio" : "Downloaden audio",
    "Keyboard shortcut" : "Sneltoets",
    "Description" : "Beschrijving",
    "right" : "rechts",
    "Jump to next article" : "Ga naar volgend artikel",
    "left" : "links",
    "Jump to previous article" : "Ga naar voorgaand artikel",
    "Toggle star article" : "Omswitchen artikelmarkering ",
    "Star article and jump to next one" : "Markeer artikel en ga naar volgende",
    "Toggle keep current article unread" : "Omswitchen hou huidig artikel ongelezen",
    "Open article in new tab" : "Open artikel in nieuwe tab",
    "Toggle expand article in compact view" : "Omswitchen uitgebreid artikel in compact overzicht",
    "Load next feed" : "Laad volgende feed",
    "Load previous feed" : "Laad voorgaande feed",
    "Load next folder" : "Laad volgende map",
    "Load previous folder" : "Laad voorgaande map",
    "Scroll to active navigation entry" : "Scrollen naar actieve navigatie regel",
    "Focus search field" : "Focus zoekveld",
    "Mark current article's feed/folder read" : "Markeer feed/map van huidige artikel als gelezen",
    "Web address" : "Webadres",
    "Feed exists already!" : "Feed bestaat al!",
    "Folder" : "Map",
    "No folder" : "Geen map",
    "New folder" : "Nieuwe map",
    "Folder name" : "Mapnaam",
    "Go back" : "Terug",
    "Folder exists already!" : "Map bestaat al!",
    "New Folder" : "Nieuwe map",
    "Create" : "Aanmaken",
    "Explore" : "Verkennen",
    "Update failed more than 50 times" : "Update mislukte meer dan 50 keer",
    "Deleted feed" : "Verwijderde feed",
    "Undo delete feed" : "Maak verwijderen feed ongedaan",
    "Rename" : "Naam wijzigen",
    "Menu" : "Menu",
    "Unpin feed from the top" : "Feed losmaken van boven",
    "Pin feed to the top" : "Feed bovenaan vastzetten",
    "No feed ordering" : "Geen feed sortering",
    "Reversed feed ordering" : "Omgekeerde feedvolgorde",
    "Normal feed ordering" : "Normale feedvolgorde",
    "Enable full text feed fetching" : "Inschakelen ophalen volledige tekst",
    "Disable full text feed fetching" : "Uitschakelen ophalen volledige tekst",
    "Keep updated articles as is" : "Hou de bijgewerkte artkelen zoals ze zijn",
    "Mark updated articles unread" : "Markeer bijgewerkte artikelen als ongelezen",
    "Rename feed" : "Hernoemen feed",
    "Delete feed" : "Verwijder feed",
    "Mark all articles read" : "Markeer alle artikelen als gelezen",
    "Dismiss" : "Terzijde leggen",
    "Collapse" : "Inklappen",
    "Deleted folder" : "Verwijderde map",
    "Undo delete folder" : "Maak verwijderen map ongedaan",
    "Rename folder" : "Hernoem map",
    "Delete folder" : "Verwijder map",
    "Starred" : "Ster gegeven",
    "Unread articles" : "Ongelezen artikelen",
    "All articles" : "Alle artikelen",
    "Settings" : "Instellingen",
    "Keyboard shortcuts" : "Sneltoetsen",
    "Disable mark read through scrolling" : "Niet als gelezen markeren door scrollen",
    "Compact view" : "Compact overzicht",
    "Expand articles on key navigation" : "Artikelen uitbreiden bij navigatie",
    "Show all articles" : "Toon alle artikelen",
    "Reverse ordering (oldest on top)" : "Omgekeerde volgorde (oudste boven)",
    "Subscriptions (OPML)" : "Abonnementen (OPML)",
    "Import" : "Importeer",
    "Export" : "Exporteer",
    "Error when importing: file does not contain valid OPML" : "Fout bij importeren: het bestand bevat geen geldige OPML",
    "Unread/Starred Articles" : "Ongelezen/ongemarkeerde artikelen",
    "Error when importing: file does not contain valid JSON" : "Fout tijdens het importeren: bestand bevat geen geldige JSON"
},
"nplurals=2; plural=(n != 1);");
